%global gittag R4_3_1

Name:      eclipse-pdt
Version:   4.3.1
Release:   1%{?dist}
Summary:   PHP Development Tools (PDT) Eclipse plug-in
License:   EPL
URL:       http://www.eclipse.org/pdt/
Source0:   http://git.eclipse.org/c/pdt/org.eclipse.pdt.git/snapshot/org.eclipse.pdt-%{gittag}.tar.xz

# The lexer/parser code generated by the Fedora version of jflex causes test failures at build time and buggy
# behaviour at runtime so we have pre-generated the parser code using upstream's preferred version of jflex.
# This source tarball was generated with the following commands:
#   $ code_gen.sh
Source1:   code_gen-%{gittag}.tar.xz
Source3:   code_gen.sh

# Appdata addon metadata
Source2:   eclipse-pdt.metainfo.xml

BuildArch:        noarch

BuildRequires:    eclipse-pde
BuildRequires:    eclipse-contributor-tools
BuildRequires:    eclipse-dltk >= 5.7.0
BuildRequires:    eclipse-dltk-mylyn
BuildRequires:    eclipse-dltk-tests
BuildRequires:    eclipse-mylyn-sdk
BuildRequires:    eclipse-webtools-sourceediting >= 3.8.0
BuildRequires:    eclipse-license
BuildRequires:    eclipse-p2-discovery
BuildRequires:    eclipse-tm-terminal-connectors
BuildRequires:    tycho
BuildRequires:    tycho-extras
BuildRequires:    maven-antrun-plugin
BuildRequires:    java_cup >= 0.11a-15

Requires:         eclipse-dltk >= 5.7.0
Requires:         eclipse-webtools-sourceediting >= 3.8.0
Requires:         php
Requires:         php-pecl-xdebug

%description
The PHP IDE project delivers a PHP Integrated Development Environment
framework for the Eclipse platform. This project encompasses the development
components necessary to develop PHP-based Web Applications and facilitates
extensibility. It leverages the existing Web Tools Project in providing
developers with PHP capabilities.

%package   sdk
Summary:   Eclipse PDT SDK
Requires:  eclipse-pde
Requires:  %{name} = %{version}-%{release}

%description sdk
Documentation and source for the Eclipse PHP Development Tools (PDT).

%package   tests
Summary:   Eclipse PDT Tests
Requires:  eclipse-dltk-tests
Requires:  %{name}-sdk = %{version}-%{release}

%description tests
Tests for Eclipse PHP Development Tools (PDT).

%prep
%setup -q -n org.eclipse.pdt-%{gittag}

# Extract pre-generated code
tar xf %{SOURCE1}

# Remove bundled binaries
find -name '*.class' -exec rm -f '{}' \;
find -name '*.jar' -exec rm -f '{}' \;
rm -r plugins/org.eclipse.php.core.parser/{java,src}/java_cup

# Remove plugins not needed
%pom_disable_module dev/org.eclipse.php-repository
%pom_remove_plugin org.eclipse.tycho:tycho-packaging-plugin
%pom_remove_plugin org.codehaus.mojo:sonar-maven-plugin

# Skip code generation
%pom_remove_plugin :maven-antrun-plugin plugins/org.eclipse.php.core

# Add java_cup as an OSGi dep instead of bundling
echo "Require-Bundle: java_cup" >> plugins/org.eclipse.php.core.parser/META-INF/MANIFEST.MF

# TODO Allow using mylyn bundles as maven deps in a sensible way
mkdir wikitext
pushd wikitext
for f in %{_datadir}/eclipse/droplets/mylyn-*/eclipse/plugins/org.eclipse.mylyn.wikitext.{core,core.ant,markdown.core,help.sdk}_* ; do
  bundle=$(basename ${f%.jar})
  xmvn -o install:install-file -Dfile=$f -Dpackaging=jar -DgroupId=org.eclipse.mylyn.docs \
      -DartifactId=$(echo $bundle | cut -d_ -f1) -Dversion=$(echo $bundle | cut -d_ -f2)
done
popd

# Fix restricted API access warnings
sed -i -e '/org\.junit/a\ org.hamcrest.core,' tests/org.eclipse.php.composer.tests/META-INF/MANIFEST.MF

%mvn_package "::pom::" __noinstall
%mvn_package ":*.{test,tests}" pdt-tests
%mvn_package "::jar:sources:" pdt-sdk
%mvn_package ":*.source" pdt-sdk
%mvn_package ":*.sdk" pdt-sdk
%mvn_package ":"

%build
# There are some intermittent test failures, random different
# ones each time, so ignore them for now
%mvn_build -f -j

%install
%mvn_install

install -m644 -D %{SOURCE2} %{buildroot}%{_datadir}/appdata/eclipse-pdt.metainfo.xml

%files -f .mfiles
%{_datadir}/appdata/eclipse-pdt.metainfo.xml
%license features/org.eclipse.php-feature/about.html

%files sdk -f .mfiles-pdt-sdk

%files tests -f .mfiles-pdt-tests

%changelog
* Fri May 05 2017 Mat Booth <mat.booth@redhat.com> - 4.3.1-1
- Update to latest upstream release

* Fri Mar 31 2017 Mat Booth <mat.booth@redhat.com> - 4.3.0-1
- Update to tagged release
- Add missing BR on tm-terminal

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 4.3.0-0.2.git71db832
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Wed Feb 01 2017 Mat Booth <mat.booth@redhat.com> - 4.3.0-0.1.git71db832
- Update to snapshot of next release to fix FTBFS errors

* Tue Jan 10 2017 Mat Booth <mat.booth@redhat.com> - 4.2.0-1
- Update to latest release

* Tue Oct 04 2016 Mat Booth <mat.booth@redhat.com> - 4.1.0-2
- Add missing BRs

* Tue Oct 04 2016 Mat Booth <mat.booth@redhat.com> - 4.1.0-1
- Update to 4.1.0 release
- Remove old obsoletes

* Thu Jul 14 2016 Mat Booth <mat.booth@redhat.com> - 4.0.0-2
- Fix BRs

* Mon Jul 04 2016 Mat Booth <mat.booth@redhat.com> - 4.0.0-1
- Update to Neon release and fix FTBFS
- rhbz#1348274, rhbz#1348942

* Tue Mar 08 2016 Mat Booth <mat.booth@redhat.com> - 3.7.0-1
- Update to Mars.2 release

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 3.6.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sun Nov 29 2015 Mat Booth <mat.booth@redhat.com> - 3.6.0-3
- Ignore intermittant test failures

* Tue Nov 17 2015 Mat Booth <mat.booth@redhat.com> - 3.6.0-2
- Re-generate lexer/parser code
- Add patch to fix intermittant test failures

* Wed Oct 07 2015 Mat Booth <mat.booth@redhat.com> - 3.6.0-1
- Update to Mars.1 release

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.3.1-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Fri May 8 2015 Alexander Kurtakov <akurtako@redhat.com> 3.3.1-6
- Fix build failure with Mars.

* Thu Sep 25 2014 Mikolaj Izdebski <mizdebsk@redhat.com> - 3.3.1-5
- Rebuild to regenerate auto requires, once again

* Wed Sep 24 2014 Mat Booth <mat.booth@redhat.com> - 3.3.1-4
- Rebuild to regenerate auto requires

* Tue Sep 23 2014 Mat Booth <mat.booth@redhat.com> - 3.3.1-3
- Build/install with xmvn

* Tue Sep 23 2014 Mat Booth <mat.booth@redhat.com> - 3.3.1-2
- Unzip feature bundles on installation
- Add dep on commons-lang
- Add appdata addon metadata
- Drop mylyn sub-package, just install it with main package

* Mon Sep 22 2014 Mat Booth <mat.booth@redhat.com> - 3.3.1-1
- Update to latest upstream
- Drop unneeded patch

* Tue Jun 24 2014 Mat Booth <mat.booth@redhat.com> - 3.3.0-3
- No longer need to copy license feature on F20

* Mon Jun 16 2014 Mat Booth <mat.booth@redhat.com> - 3.3.0-2
- Copy shared license feature, allowing building on F20

* Fri Jun 13 2014 Mat Booth <mat.booth@redhat.com> - 3.3.0-1
- Update to latest release
- Use pre-generated parser code

* Tue Mar 11 2014 Mat Booth <fedora@matbooth.co.uk> - 3.2.0-3.git0be0c838
- Enable tests, run them with a virtual frame buffer

* Mon Feb 10 2014 Mat Booth <fedora@matbooth.co.uk> 3.2.0-2.git0be0c838
- Update to post-release snapshot for PHP 5.5 and Eclipse >= 4.3 support
- Drop upstreamed patch

* Sat Aug 31 2013 Mat Booth <fedora@matbooth.co.uk> 3.2.0-1
- Initial release, based loosely on the eclipse-dltk spec.
